==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "one: Thời gian"

]
, "Account"
: "Tài khoản"

, "Time Account (Number - Title)"
: "Tài khoản thời gian (số - tiêu đề)"

, "Billable"
: "Có thể trả"

, "Cleared in"
: "Xóa trong"

, "Invoice"
: ""

, "Cleared"
: "Đã xóa"

, "Date"
: "Ngày"

, "Start time"
: "Thời gian bắt đầu"

, "End time"
: ""

, "Duration"
: "Thời lượng"

, "Description"
: "Mô tả"

, "Type"
: ""

, "Time Account closed"
: "Tài khoản thời gian đã đóng"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""

]
, "Contract"
: "Hợp đồng"

, "Title"
: "Tiêu đề"

, "Number"
: "Số"

, "Price"
: ""

, "Status"
: "Trạng thái"

, "Billed"
: "Đã trả"

, "Cleared at"
: "Xóa vào"

, "Booking deadline"
: "Hạn đăng ký"

, "Responsible"
: ""

, "Cost Center"
: "Trung tâm giá"

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "one: Tài khoản thời gian\nother: Tài khoản thời gian"

]
, "Time Account - Status"
: "Tài khoản thời gian - Trạng thái"

, "closed"
: "đã đóng"

, "open"
: "mở"

, "Not a valid time"
: "Không là 1 thời gian hợp lệ"

, "Time Account - Billed"
: "Tài khoản theo thời gian - Đã trả"

, "not yet billed"
: "chưa trả"

, "to bill"
: "phải trả"

, "billed"
: "đã trả"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""

]
, "Favorite"
: ""

, "Cleared In"
: "Đã xóa trong"

, "Select Time Account..."
: "Chọn tài khoản thời gian..."

, "Start"
: "Bắt đầu"

, "not set"
: "chưa đặt"

, "End"
: ""

, "Enter description..."
: "Nhập mô tả"

, "Need for Clarification"
: ""

, "Failed"
: "Lỗi"

, "Could not save {0}."
: "Không thể lưu lại {0}"

, "Booking deadline for this Timeaccount has been exceeded."
: "Đặt thời gian kết thúc cho tài khoản thời gian sẽ kết thúc."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""

]
, "Book Own"
: "Đặt của tôi"

, "The grant to add Timesheets to this Timeaccount"
: "Quyền để tạo chấm công tới Timeaccount này"

, "View All"
: "Xem tất cả"

, "The grant to view Timesheets of other users"
: "Quyền để xem chấm công cho người dùng khác"

, "Book All"
: "Đặt tất cả"

, "The grant to add Timesheets for other users"
: "Quyền thêm chấm công cho người dùng khác"

, "Manage Clearing"
: "Quản lý xóa dữ liệu"

, "The grant to manage clearing of Timesheets"
: "Quyền để quản lý việc xóa chấm công."

, "without contract"
: "Không có hợp đồng"

, "without responsible"
: ""

, "timeframe"
: "khung thời gian"

, "summary"
: "Tóm tắt"

, "Total Timesheets"
: "Tổng thời gian chấm công"

, "Billable Timesheets"
: "Thời gian tính phí"

, "Total Time"
: "Tổng thời gian"

, "Time of Billable Timesheets"
: "Thời gian chấm công tính phí"

, "Detail"
: "Chi tiết"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Xuất dữ liệu tính công"

, "Export as ODS"
: "Xuất dữ liệu dạng ODS"

, "Export as CSV"
: "Xuất dữ liệu dạng CSV"

, "Export as ..."
: "Xuất dạng ..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Đơn vị"

, "Unit Price"
: "Giá đơn vị"

, "Budget"
: "Quỹ"

, "Timesheets are billable"
: "Chấm công có hóa đơn"

, "Access"
: "Truy cập"

, "Permissions"
: "Quyền"

, "Show closed"
: "Hiển thị bị đóng"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Cấu hình xuất dữ liệu chấm công ODS"

, "Use this configuration for the timesheet ODS export."
: "Sử dụng cấu hình này cho việc xuất dữ liệu chấm công ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "mặc định"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "không"

, "last week"
: "tuần trước"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Quản lý tài khoản thời gian"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Thêm, sửa và xóa tài khoản thời gian (bao gồm mọi quyền nhật ký chấm công)"

, "Add timeaccounts"
: "Thêm tài khoản thời gian"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: "Quản lý lối tắt dự án dùng chung"

, "Create or update shared timesheet favorites"
: ""

, "My Timesheets today"
: "Chấm công hôm nay của tôi"

, "My Timesheets this week"
: "Chấm công tuần này của tôi"

, "My Timesheets last week"
: "Chấm công tuần trước của tôi"

, "My Timesheets this month"
: "Chấm công tháng này của tôi"

, "My Timesheets last month"
: "Chấm công tháng trước của tôi"

, "Timeaccounts to bill"
: "Tài khoản thời gian cần thanh toán"

, "Timeaccounts not yet billed"
: "Tài khoản thời gian chưa thanh toán"

, "Timeaccounts already billed"
: "Tài khoản thời gian đã thanh toán"

, "Timetracker"
: "Bộ đếm thời gian"

, "Timesheet"
: "one: Thời gian"

, "Timeaccount"
: ""

, "Time Account"
: "one: Tài khoản thời gian\nother: Tài khoản thời gian"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "khung thời gian"

, "summary"
: "Tóm tắt"

, "Total Timesheets"
: "Tổng thời gian chấm công"

, "Billable Timesheets"
: "Thời gian tính phí"

, "Total Time"
: "Tổng thời gian"

, "Time of Billable Timesheets"
: "Thời gian chấm công tính phí"

, "Description"
: "Mô tả"

, "Detail"
: "Chi tiết"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Xuất dữ liệu tính công"

, "Export as ODS"
: "Xuất dữ liệu dạng ODS"

, "Export as CSV"
: "Xuất dữ liệu dạng CSV"

, "Export as ..."
: "Xuất dạng ..."

, "Timesheet, Timesheets"
: [
  "one: Thời gian"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""

]
, "Failed"
: "Lỗi"

, "Could not save {0}."
: "Không thể lưu lại {0}"

, "Booking deadline for this Timeaccount has been exceeded."
: "Đặt thời gian kết thúc cho tài khoản thời gian sẽ kết thúc."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Hợp đồng"

, "without contract"
: "Không có hợp đồng"

, "Add New Timeaccount"
: ""

, "Unit"
: "Đơn vị"

, "Unit Price"
: "Giá đơn vị"

, "Factor"
: ""

, "Budget"
: "Quỹ"

, "Status"
: "Trạng thái"

, "closed"
: "đã đóng"

, "open"
: "mở"

, "Cleared In"
: "Đã xóa trong"

, "Cleared at"
: "Xóa vào"

, "Cost Center"
: "Trung tâm giá"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Chấm công có hóa đơn"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "one: Tài khoản thời gian\nother: Tài khoản thời gian"

]
, "Number"
: "Số"

, "Title"
: "Tiêu đề"

, "Access"
: "Truy cập"

, "Permissions"
: "Quyền"

, "Time Account - Billed"
: "Tài khoản theo thời gian - Đã trả"

, "not yet billed"
: "chưa trả"

, "to bill"
: "phải trả"

, "billed"
: "đã trả"

, "Time Account - Status"
: "Tài khoản thời gian - Trạng thái"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""

]
, "Book Own"
: "Đặt của tôi"

, "The grant to add Timesheets to this Timeaccount"
: "Quyền để tạo chấm công tới Timeaccount này"

, "View All"
: "Xem tất cả"

, "The grant to view Timesheets of other users"
: "Quyền để xem chấm công cho người dùng khác"

, "Book All"
: "Đặt tất cả"

, "The grant to add Timesheets for other users"
: "Quyền thêm chấm công cho người dùng khác"

, "Manage Clearing"
: "Quản lý xóa dữ liệu"

, "The grant to manage clearing of Timesheets"
: "Quyền để quản lý việc xóa chấm công."

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""

]
, "Favorite"
: ""

, "Show closed"
: "Hiển thị bị đóng"

, "Timesheets ODS export configuration"
: "Cấu hình xuất dữ liệu chấm công ODS"

, "Use this configuration for the timesheet ODS export."
: "Sử dụng cấu hình này cho việc xuất dữ liệu chấm công ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "mặc định"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "không"

, "last week"
: "tuần trước"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Xóa trong"

, "Billed"
: "Đã trả"

, "Booking deadline"
: "Hạn đăng ký"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Tài khoản"

, "Time Account (Number - Title)"
: "Tài khoản thời gian (số - tiêu đề)"

, "Billable"
: "Có thể trả"

, "Cleared"
: "Đã xóa"

, "Date"
: "Ngày"

, "Start time"
: "Thời gian bắt đầu"

, "End time"
: ""

, "Duration"
: "Thời lượng"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Tài khoản thời gian đã đóng"

, "Timetracker"
: "Bộ đếm thời gian"

, "Timeaccounts to bill"
: "Tài khoản thời gian cần thanh toán"

, "Timeaccounts not yet billed"
: "Tài khoản thời gian chưa thanh toán"

, "Timeaccounts already billed"
: "Tài khoản thời gian đã thanh toán"

, "My Timesheets today"
: "Chấm công hôm nay của tôi"

, "My Timesheets this week"
: "Chấm công tuần này của tôi"

, "My Timesheets last week"
: "Chấm công tuần trước của tôi"

, "My Timesheets this month"
: "Chấm công tháng này của tôi"

, "My Timesheets last month"
: "Chấm công tháng trước của tôi"

, "Manage timeaccounts"
: "Quản lý tài khoản thời gian"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Thêm, sửa và xóa tài khoản thời gian (bao gồm mọi quyền nhật ký chấm công)"

, "Add timeaccounts"
: "Thêm tài khoản thời gian"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: "Quản lý lối tắt dự án dùng chung"

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "one: Thời gian"

, "Timeaccount"
: ""

, "Time Account"
: "one: Tài khoản thời gian\nother: Tài khoản thời gian"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
